==> cscec5b-sync-impl-3.0.0-20210415.021844-47-sources.jar: com/ejianc/business/sync/controller/SyncController.java <==
package com.ejianc.business.sync.controller;

import com.ejianc.business.sync.service.ICmSubListService;
import com.ejianc.business.sync.vo.OddSyncVo;
import com.ejianc.business.sync.vo.OddVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;

@Controller
@RequestMapping("sync")
public class SyncController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private ICmSubListService cmSubListService;

    /**
     * 零星用工同步至nc中间表
     * @param oddVO
     * @return
     */
    @RequestMapping(value = "/syncOdd", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> syncOdd(@RequestBody OddVO oddVO) {
        logger.debug("------零星用工同步至nc中间表");
        return cmSubListService.syncOdd(oddVO);
    }

    @GetMapping("updatestatus")
    @ResponseBody
    public CommonResponse<OddSyncVo> updateStatus(Integer day) {
        //Integer day = 2; // NC没有维护ts 先按照入的ts取最近2个月的数据更新
        return cmSubListService.updateNcFlag(day);

    }

    /**
     * 查看nc是否同步
     * @param id
     * @return
     */
    @GetMapping("syncFlag")
    @ResponseBody
    public CommonResponse<Boolean> syncFlag(Long id) {
        logger.debug("------查看nc是否同步");
        return cmSubListService.syncFlag(id);
    }

    /**
     * 删除同步的中间表
     * @param id
     * @return
     */
    @GetMapping("delSync")
    @ResponseBody
    public CommonResponse<Boolean> delSync(Long id) {
        logger.debug("------删除同步的中间表");
        return cmSubListService.delSync(id);
    }
}

==> cscec5b-sync-impl-3.0.1-20221227.020801-21-sources.jar: com/ejianc/business/sync/controller/SyncController.java <==
package com.ejianc.business.sync.controller;

import com.ejianc.business.sync.service.ICmSubListService;
import com.ejianc.business.sync.vo.OddSyncVo;
import com.ejianc.business.sync.vo.OddVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;

@Controller
@RequestMapping("sync")
public class SyncController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private ICmSubListService cmSubListService;

    /**
     * 零星用工同步至nc中间表
     * @param oddVO
     * @return
     */
    @RequestMapping(value = "/syncOdd", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> syncOdd(@RequestBody OddVO oddVO) {
        logger.debug("------零星用工同步至nc中间表");
        return cmSubListService.syncOdd(oddVO);
    }

    @GetMapping("updatestatus")
    @ResponseBody
    public CommonResponse<OddSyncVo> updateStatus(Integer day) {
        //Integer day = 2; // NC没有维护ts 先按照入的ts取最近2个月的数据更新
        return cmSubListService.updateNcFlag(day);

    }

    /**
     * 查看nc是否同步
     * @param id
     * @return
     */
    @GetMapping("syncFlag")
    @ResponseBody
    public CommonResponse<Boolean> syncFlag(Long id) {
        logger.debug("------查看nc是否同步");
        return cmSubListService.syncFlag(id);
    }

    /**
     * 删除同步的中间表
     * @param id
     * @return
     */
    @GetMapping("delSync")
    @ResponseBody
    public CommonResponse<Boolean> delSync(Long id) {
        logger.debug("------删除同步的中间表");
        return cmSubListService.delSync(id);
    }

    /**
     * 零星用工同步至nc中间表
     * @param oddVO
     * @return
     */
    @RequestMapping(value = "/syncOddImport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> syncOddImport(@RequestBody OddVO oddVO) {
        logger.debug("------零星用工同步至nc中间表");
        return cmSubListService.syncOddImport(oddVO);
    }
}
